@@ -416,8 +416,12 @@ class VariableClAutopartitionDefaultFormat(Variable):
         return FileSystemManager.defaultFS['hdd']
 
     def choice(self):
-        return list(sorted([k for k,v in FileSystemManager.supportFS.items()
-                if v.get('auto',True)]))
+        allfs = set([k for k,v in FileSystemManager.supportFS.items()
+                     if v.get('auto',True)])
+        availFS = set(self.Select('os_format_type',
+                                  where='os_format_use',
+                                  eq='yes'))
+        return list(sorted(allfs, availFS))
 
 
 class VariableClAutopartitionRootFormat(VariableClAutopartitionDefaultFormat):
